#
# spec file for package perl-PAR-Packer
#
# Copyright (c) 2017 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-PAR-Packer
Version:        1.036
Release:        lp150.1.25
%define cpan_name PAR-Packer
Summary:        PAR Packager
License:        GPL-1.0+ or Artistic-1.0
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/PAR-Packer/
Source:         http://www.cpan.org/authors/id/R/RS/RSCHUPP/%{cpan_name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Archive::Zip) >= 1
BuildRequires:  perl(Compress::Zlib) >= 1.3
BuildRequires:  perl(Getopt::ArgvFile) >= 1.07
BuildRequires:  perl(Module::ScanDeps) >= 1.09
BuildRequires:  perl(PAR) >= 1.005
BuildRequires:  perl(PAR::Dist) >= 0.22
Requires:       perl(Archive::Zip) >= 1
Requires:       perl(Compress::Zlib) >= 1.3
Requires:       perl(Getopt::ArgvFile) >= 1.07
Requires:       perl(Module::ScanDeps) >= 1.09
Requires:       perl(PAR) >= 1.005
Requires:       perl(PAR::Dist) >= 0.22
Recommends:     perl(Digest) >= Module::Signature
%{perl_requires}
%{?libperl_requires}

%description
This module implements the *App::Packer::Backend* interface, for generating
stand-alone executables, perl scripts and PAR files.

Currently, this module is used by the command line tool *pp* internally, as
well as by the contributed _contrib/gui_pp/gpp_ program.

Since version 0.97 of PAR, this module and its related tools such as 'pp'
have been stripped from the PAR distribution and are now distributed as the
'PAR-Packer' distribution so that PAR users need not necessarily have a C
compiler.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f -print0 | xargs -0 chmod 644

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%{__make}

%check
%{__make} test || true

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%clean
%{__rm} -rf %{buildroot}

%files -f %{name}.files
%defattr(-,root,root,755)
%doc AUTHORS Changes README

%changelog
* Wed Feb  1 2017 josef.moellers@suse.com
- Update to 1.036:
  - Fix RT#118094: Race condition exists when building cache for pp built executables
  - guard against concurrent extraction attempts
  - bump "requires" on PAR to a version with additional guards
  - Fix RT#118903: Does not install when '.' is not in @INC
  - apply patch from Graham Ollis (PLICEASE), thanks!
  - make the Module::Install stuff work in the "author" case
    NOTE: "use lib '.'" does *not* work in this case
  - Move to GitHub. Thanks, OpenFoundry, for years of service.
  - add Perl_5 LICENSE file, make "repository" point to GitHub
  - always refer to the included LICENSE file
  - point bug reports to bug-par-packer@rt.cpan.org
  - add an empty file "inc/.author/.keep" as Git doesn't track empty
    directories
  - Fix RT #118053: Problem with packed perl archive for biber on 64-bit Cygwin
  - embed cygcrypt-0.dll since it isn't (anymore) in the set of
    default Cygwin packages
  - Upgrade to Module::Install 1.17
- Update to 1.035:
  - Fix RT#116254: Compilation error under strawberry perl 5.24 x64
    s/PP_VERSION/PAR_PACKER_VERSION/ as Strawberry Perl also defines
    PP_VERSION (in c/x86_64-w64-mingw32/include/wincrypt.h)
- Update to 1.034:
  - Fix RT#116056: Fixes for Cygwin build of PAR::Packer
  - detect whether we're using a 32-bit or 64-bit perl
  - fix elision of "-l<perl lib>" from $static_ldflags
  - add $static_ldflags back to $boot_ldflags
  - Add information to packed executable about which version
    of PAR::Packer was used to build it (suggested by Johan Vromans):
  - accessible from the packaged Perl script as $PAR::Packer::VERSION
  - by looking for the string "Packed by PAR::Packer ..." in the executable
    itself (using "strings exe | grep ..." or the like)
  - Use ldd on cygwin, too
  - NOTE: a "system lib" on cygwin is either in /usr/bin
    or a Windows "system lib"
* Fri Jun 17 2016 thb@libreoffice.org
- Update to 1.033:
  - Fix RT#114229: v1.32 still won't install on strawberry perl v5.22.2
  - Drop the "re-exec myself" in myldr/internals.c
  - Really suppress generation of myldr/MYMETA.* and don't install
    man pages for myldr/{Dynamic,Static}.pm
- Update to 1.032:
  - Unbreak PAR::Packer for Perl 5.23.9 and higher
  - Fix RT#114155: Makefile.PL error - not loading ExtUtils::MakeMaker
  - extract-embedded.pl: show starting offset of embedded files
- Update to 1.031:
  - Fix RT#113618: Strange issue with not packing libperl.dylib
  - Implement namespace options for "-M" like ActiveState's perlapp
  - Fix RT#113463: Fix spelling error in manpage
- Update to 1.030:
  - Fix RT#111455: unable to use -x and -u with pp
  - Fix RT#110480: Unpacking exe: File exists
  - Fix RT#111896: PAR Question Solaris 10
  - file2c.pl: switch back from array of unsiged to (hex encoded) strings.
  - Skip a test if Archive::Unzip::Burst is detected (this messes up expected
    mtimes for extracted files).
  - Make a test work with early versions of Perl 5.8.x (x < 9) that have a bug
    with compiled regexes and the /m modifier.
- Update to 1.029:
  - Add option "-u" ("--unicode") to pp to explicitly package Unicode support
  - Remove all references to http://par.perl.org/, doesn't exist anymore
  - Remove Internals::PAR::CLEARSTACK
- Update to 1.028:
  - Fix RT#109123: v1.027 tests are not passed under windows
- Update to 1.027:
  - Add option -M Foo::Bar:: to pp (note the trailing double colon)
  - Fix RT#109110: Incompatible with Module::ScanDeps 1.20
- Update to 1.026:
  - Fix RT#101800: [PATCH] Reinstate files to inc dir if deleted by external process
  - Find the "\nPAR.pm\n" signature in a .par (or packed executable)
  - Fix RT#104635 for PAR-Packer: IO error the first time an executable built by the packer
  - Fix RT#104509: Problem signing PAR file,
    and RT#104560: [PATCH] list added files in manifest
  - Make MIME::Types work "out of the box"
  - Bump requirement on PAR (for the fix for RT #103861), add a test.
  - Update tkpp ito 1.5:
  - Make pp fail when an unknown option is encountered.
  - Remove PAR::Packer::_append_parl(), not called anywhere.
  - Add license; update repository OpenFoundry repository URL
- Update to 1.025:
  - Fix PAR::Packer "make test" problem with Strawberry Portable
  - Fix for PAR-Packer 1.024 with a nonstandard libperl.so name
    Patch from markus.jansen@ericsson.com, thanks!
  - Fix #101662: Prevent shared libs from being cached in memory on AIX
    Applied patch from Thoke@northpeak.org, thanks.
    Note: this is one half of the fix, the other is in PAR
- Update to 1.024:
  - Fix RT #99231: Problem with PAR::Packer 1.022 on Perl 5.20.1 and earlier
- Update to 1.023:
  - Fix RT #99231: Problem with PAR::Packer 1.022 on Perl 5.20.1 and earlier
  - Fix RT #63939: The behaviour of "pp --link ..." is subtly different between OSX and Linux
  - Bump required version of Module::ScanDeps,
    makes t/90-rt59710.t pass again on perl 5.21.x
  - die if a requested shared library (option -l) can't be found.
  - Add a patch rule so that Mozilla::CA finds its (extracted) cacert.pem file.
  - Upgrade to Module::Install 1.14.
- Update to 1.022:
  - Fix RT#98955: installation fails | Can't locate String/ShellQuote.pm
  - Simply enclose the filenames in double quotes, should work on both
  * nix and Windows in all reasonable scenarios.
  - Drop incorrectly specified 'Digital signature support' "feature": simply
    "recommends" the required modules.
- Update to 1.021:
  - Fix #98791: PAR-Packer fails to build with DWIMPerl/Strawberry Perl due to unquoted path name
- Update to 1.020:
  - Implement option --xargs for pp
  - Update to Module::Install 1.10
- Update to 1.019:
  - Fix RT #96288: PAR::Packer unable to build under Win32/ActivePerl v5.14.2
    RT #96739: "bsd_glob" is not defined on perl 5.14.x and earlier
    RT #97018 (Issue while upgrading PAR::Packer )
  - Fix RT #59224 (make error with version 1.006 on aix 5.3)
  - Update documentation wrt the name of the cache directory.
- Update to 1.018:
  - [DJIBEL] tkpp 1.4 : Since PAR::Packer 1.015, tkpp doesn't work
  - Use bsd_glob() instead of glob() to avoid problems with patterns that
    contain whitespace
  - Fix RT #93008: install failure with ubuntu / puppet
* Tue May 13 2014 tbehrens@suse.com
- Update to 1.017:
  RT #84588: OSX: incorrect detection of gcc (unsupported option '-static-libgcc')
  merged with:
  - RT #90198: PAR::Packer fails to compile in Mac OS X 10.9 Mavericks
  - RT #91086: PAR-Packer-1.016 fails to install on OSX)
  clang on OSX pretends to be gcc, but doesn't implement gcc's option "-static-libgcc"
  - use this option only on Windows (when using the MingW toolchain).
  Drop a test that was using Inline::C just to wrap native execvp().
  - It caused failures on CPAN Testers (if accidentally Inline was
    installed) that were unrelated to PAR::Packer.
- Update to 1.016:
    RT #90870: Segmentation fault (core dumped) (MooX::Options)
  - any "die" in a packed executable causes the executable to segfault
    (at least on Linux and Perl 5.18.1)
  - remove a line from XS code that sets an internal perl variable
* Wed Nov 13 2013 pth@suse.de
- Update to 1.015:
  RT #82916: Terminating during unpack results in corrupted cache,
    failure on next start
  - apply (slightly modified) patch from shutton@pobox.com, thanks!
  RT #88297 (-M crashes pp if option contains backslashes)
  - _add_file(): do _not_ use $zip->memberNamed(...) to refer to the
    just added Archive::Zip::Member; instead use the
    return value of $zip->addFile or $zip->addString
  minor changes
  - use File::Spec::Functions, get rid of ugly File::Spec->... calls
  - set $pre_res using catfile() instead of hardcoding a backslash;
    this might help on Cygwin
  - fix -Mblib option for run_with_inc.pl: we want the blib in the top
    level directory
* Thu Sep  5 2013 mls@suse.de
- add libperl_requires, as we link against libperl and thus
  need a specific version of perl
* Thu Jan 10 2013 ro@suse.de
- update to 1.014
  * tkpp 1.3 : --addfile option in GUI updated :
  * Bug fixes, etc.
- update to 1.013
  * New version of Tkpp (Version 1.2) (cf. RT #69517)
  * Bug fixes, etc.
- update to 1.012
  * Bug fixes, etc.
- update to 1.011
  * Bug fixes, etc.
* Wed May 23 2012 cfarrell@suse.com
- license update: GPL-1.0+ or Artistic-1.0
  SPDX syntax (http://www.spdx.org/licenses)
* Thu Jul 14 2011 pth@suse.de
- Update to 1.010
  * Bug fixes, etc.
  - Adapt for changes in XSloader.pm (>= 0.14)
    The old rule in PatchContent.pm no longer works with this version;
    this effectively disables how PAR::Packer intercepts loading of DLLs.
    Add a new rule for the code in recent XSloader.pm.
    NOTE: This problem affected all users of Perl >= 5.14.0 as this
    was the first stable release to include XSLoader 0.14.
    Also affected: Strawberry (at least) 5.12.3 which also comes
    with XSLoader 0.14.
  - RT #67681: can't write file
    During packing several temp files are created in the user's
    working directory - this will fail if the working directory is read-only.
    Fix up all calls to File::Temp::tempfile with TMPDIR => 1
    and drop the bogus check whether cwd is writable.
    NOTE: test 32 of t/20-pp.t may fail. I have received conflicting reports
    about this, but just wanted to make a release to get wider coverage.
* Sun May  1 2011 coolo@opensuse.org
- updated to 1.009
  * Bug fixes, etc.
  - RT #53463: PAR::Packer 1.002 on HPUX 11.23 PA-RISC issue
    (HPUX) patch from Lars-Gunnar Taube
  - add SHLIB_PATH to ld_path_keys in myldr/mktmpdir.c
  - call "chatr +s enable ..." on the extracted custom perl
  - RT #65535: Unable to run perl script packaged with pp under cygwin
    on another Windows XP installation
  - lib/PAR/Filter/PatchContent.pm: patch AutoLoader.pm to add "cygwin"
    to the list of "is_dosish" $^O identifiers; otherwise
    AutoLoader::find_filename() will mangle filenames that start with
    a drive letter
  - script/par.pl: use PAR::Filter::PatchContent to patch any modules
    embedded in the packed excutable; this supersedes the ad hoc
    patching of XSLoader.pm and will now also patch AutoLoader.pm
  - myldr/Makefile.PL: when generating $parl_exe or $parldy_exe make
    sure that we use the PAR::* modules (e.g PAR::Filter::PatchContent)
    from the build environment rather than a possibly
    installed older version
  - "Fix" #64485: pp PodStrip module included
    document how to inhibit pod stripping (copied from PAR.pm POD)
  - bump required Module::ScanDeps to 1.01 (hopefully fixes failures
    in t/90-rt59710.t with Perl 5.13.x)
  - reworked the build system a bit to fix recurring problems with dmake
    on Windows and parallel makes in general:
  - copy myldr/{parl,parldyn} to blib/scripts from myldr/Makefile
  - myldr/Makefile was completely handcrafted; try to generate it
    using standard ExtUtils::MakeMaker tools as much as possible
  - generate myldr/{Dynamic,Static}.pm from templates {Dynamic,Static}.in
  - rename static.c to boot.c
  - add "configure_requires" for ExtUtils::Embed
  - pick up some POD spelling fixes from Debian
    (thanks, Jonathan Yu <jawnsy@cpan.org>)
* Tue Nov 23 2010 pth@suse.de
- Package as bz2 to have it build on SLE10.
* Tue Nov 23 2010 pth@suse.de
- initial package 1.008
  * created by cpanspec 1.78
- BuildRequire perl(Test::Pod).
- Don't run multiple instances of make as Makefile can't cope with it.
- Create a separate spec for running the tests.
